@@ -1,7 +1,7 @@
 ###
-### R routines for the R package dlnm (c) Antonio Gasparrini 2013
+### R routines for the R package dlnm (c) Antonio Gasparrini 2013-2014
 #
-`logknots` <-
+logknots <-
 function(x, nk=NULL, fun="ns", df=1, degree=3, int=TRUE) {
 #
 ################################################################################
@@ -9,7 +9,7 @@ function(x, nk=NULL, fun="ns", df=1, degree=3, int=TRUE) {
   x <- as.vector(x)
 #
   # IF LENGTH OF x 1 OR 2, INTERPRETED AS A LAG RANGE, OTHERWISE TAKE THE RANGE
-  range <- if(length(x)<3L) .mklag(x) else range(x,na.rm=TRUE) 
+  range <- if(length(x)<3L) mklag(x) else range(x,na.rm=TRUE) 
   if(diff(range)==0) stop("range must be >0")
 #
   # CHOOSE NUMBER OF KNOTS IF NOT PROVIDED
